==> script.mrknow.urlresolver-2016.11.1.2.zip: script.mrknow.urlresolver/lib/urlresolver9/plugins/videorev.py <==
"""
    OVERALL CREDIT TO:
        t0mm0, Eldorado, VOINAGE, BSTRDMKR, tknorris, smokdpi, TheHighway

    urlresolver XBMC Addon
    Copyright (C) 2011 t0mm0

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import re
from lib import helpers
from urlresolver9 import common
from urlresolver9.resolver import UrlResolver, ResolverError

class VideoRevResolver(UrlResolver):
    name = "videorev"
    domains = ['videorev.cc']
    pattern = '(?://|\.)(videorev\.cc)/([a-zA-Z0-9]+)\.html'

    def __init__(self):
        self.net = common.Net()

    def get_media_url(self, host, media_id):
        web_url = self.get_url(host, media_id)
        response = self.net.http_GET(web_url)
        html = response.content

        if html:
            smil_id = re.search('([a-zA-Z0-9]+)(?=\|smil)', html).groups()[0]
            smil_url = 'http://%s/%s.smil' % (host, smil_id)
            result = self.net.http_GET(smil_url).content
            
            base = re.search('base="(.+?)"', result).groups()[0]
            srcs = re.findall('src="(.+?)"', result)
            try:
                res = re.findall('width="(.+?)"', result)
            except:
                res = res = re.findall('height="(.+?)"', result)

            i = 0
            sources = []
            for src in srcs:
                sources.append([str(res[i]), '%s playpath=%s' % (base, src)])
                i += 1
                
            source = helpers.pick_source(sources, self.get_setting('auto_pick') == 'true')
            source = source.encode('utf-8')

            return source

        raise ResolverError('No playable video found.')

    def get_url(self, host, media_id):
        return self._default_get_url(host, media_id, 'http://{host}/{media_id}.html')

    @classmethod
    def get_settings_xml(cls):
        xml = super(cls, cls).get_settings_xml()
        xml.append('<setting id="%s_auto_pick" type="bool" label="Automatically pick best quality" default="false" visible="true"/>' % (cls.__name__))
        return xml

==> script.mrknow.urlresolver-2017.06.14.1.zip: script.mrknow.urlresolver/lib/urlresolver9/plugins/videorev.py <==
"""
    OVERALL CREDIT TO:
        t0mm0, Eldorado, VOINAGE, BSTRDMKR, tknorris, smokdpi, TheHighway

    urlresolver XBMC Addon
    Copyright (C) 2011 t0mm0

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import re
from lib import helpers
from urlresolver9 import common
from urlresolver9.resolver import UrlResolver, ResolverError

class VideoRevResolver(UrlResolver):
    name = "videorev"
    domains = ['videorev.cc']
    pattern = '(?://|\.)(videorev\.cc)/([a-zA-Z0-9]+)\.html'

    def __init__(self):
        self.net = common.Net()

    def get_media_url(self, host, media_id):
        web_url = self.get_url(host, media_id)
        headers = {'User-Agent': common.FF_USER_AGENT}
        response = self.net.http_GET(web_url, headers=headers)
        html = response.content

        if html:
            smil_id = re.search('([a-zA-Z0-9]+)(?=\|smil)', html).groups()[0]
            smil_url = 'http://%s/%s.smil' % (host, smil_id)
            smil = self.net.http_GET(smil_url, headers=headers).content
            sources = helpers.parse_smil_source_list(smil)
            return helpers.pick_source(sources) + helpers.append_headers(headers)

        raise ResolverError('No playable video found.')

    def get_url(self, host, media_id):
        return self._default_get_url(host, media_id, 'http://{host}/{media_id}.html')
